summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatus.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-22 00:30:31 +0000
commit69cac65817d949cda2672ec4f0aa73d5e66a0ba1 (patch)
tree073fde0496ea90eb5bf5cffe66a8da43a9f55fbc /kopete/libkopete/kopeteonlinestatus.h
parent3467e6464beac3a162839bf7078e22e3a74d73e7 (diff)
downloadtdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.tar.gz
tdenetwork-69cac65817d949cda2672ec4f0aa73d5e66a0ba1.zip
TQt4 port kdenetwork
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237912 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatus.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatus.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/libkopete/kopeteonlinestatus.h b/kopete/libkopete/kopeteonlinestatus.h
index dfdb39df..a1296f17 100644
--- a/kopete/libkopete/kopeteonlinestatus.h
+++ b/kopete/libkopete/kopeteonlinestatus.h
@@ -1,5 +1,5 @@
/*
- kopeteonlinestatus.h - Kopete Online Status
+ kopeteonlinestatus.h - Kopete Online tqStatus
Copyright (c) 2003 by Martijn Klingens <klingens@kde.org>
Copyright (c) 2003 by Duncan Mac-Vicar Prett <duncan@kde.org>
@@ -128,7 +128,7 @@ public:
* Any internal status value > 0x80000000 is reserved for internal
* libkopete use. This enumeration lists the currently known values.
*/
- enum ReservedInternalStatus
+ enum ReservedInternaltqStatus
{
/**
* The account this contact belongs to is offline. Used with
@@ -167,9 +167,9 @@ public:
* @param internalStatus is the status as used internally by the protocol.
* This status is usually a lot more fine-grained than the status as used
* by libkopete and should be unique per protocol.
- * @param overlayIcons is a list of QStrings which are the name of status
+ * @param overlayIcons is a list of TQStrings which are the name of status
* icons to be used by the KDE icon loader. (Statuses which don't have icons
- * to overlay like Online and Offline should use TQString::null as icon
+ * to overlay like Online and Offline should use TQString() as icon
* name ). NOTE if the string is a movie ( *.mng ) it must be the first string in the list.
* TODO: KDE4 sort out movies and overlay icons.
* @param description is a description in e.g. tooltips.
@@ -202,8 +202,8 @@ public:
* This status is usually a lot more fine-grained than the status as used
* by libkopete and should be unique per protocol.
* @param overlayIcon is a string returning the name of the status icon to be
* used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
* Online and Offline should use TQString::null as icon string)
* @param description is a description in e.g. tooltips.
* @param caption is the text of the action in the menu
* @param categories the categories this online status is in
@@ -332,7 +332,7 @@ public:
*
* You can access icons with this method that have previously been rendered
* using mimeSourceFor(). Note that only a cache lookup will be done, so
- * if the cache has been invalidated due to a change of icon sets between
+ * if the cache has been tqinvalidated due to a change of icon sets between
* requesting the key (thus rendering the icon) and trying to access the
* icon by key, an invalid pixmap will be returned.
*/
@@ -389,7 +389,7 @@ public:
static TQString statusTypeToString(OnlineStatus::StatusType status);
/**
- * \brief returns a StatusType from a QString
+ * \brief returns a StatusType from a TQString
*
* Static method to convert a TQString representing a StatusType to a StatusType to avoid
* many issues when saving StatusType to disk
@@ -202,8 +202,8 @@ public:
* by libkopete and should be unique per protocol.
* @param overlayIcon is a string returning the name of the status icon to be
- * used by the KDE icon loader. (Status whiwh doesn't have icon to overlay like
- * Online and Offline should use TQString::null as icon string)
+ * used by the KDE icon loader. (tqStatus whiwh doesn't have icon to overlay like
+ * Online and Offline should use TQString() as icon string)
* @param description is a description in e.g. tooltips.
* @param caption is the text of the action in the menu